@@ -473,11 +473,11 @@
 		} else{
 			mu = rep(0, N+i+n.ahead-1)
 		}
-		if(modelinc[7]>0){
+		#if(modelinc[7]>0){
 			omega = rep(ipars[idx["omega",1]:idx["omega",2], 1], N+i+n.ahead-1)
-		} else {
-			omega = rep(0, N+i+n.ahead-1)
-		}
+		#} else {
+		#	omega = rep(0, N+i+n.ahead-1)
+		#}
 		# no look-ahead
 		h = c(sigmafilter[1:(N+i-1)], rep(0, n.ahead))
 		epsx = c(resfilter[1:(N+i-1)], rep(0, n.ahead))
@@ -624,11 +624,11 @@
 		} else{
 			mu = rep(0, N+i+n.ahead-1)
 		}
-		if(modelinc[7]>0){
+		#if(modelinc[7]>0){
 			omega = rep(ipars[idx["omega",1]:idx["omega",2], 1], N+i+n.ahead-1)
-		} else {
-			omega = rep(0, N+i+n.ahead-1)
-		}
+		#} else {
+		#	omega = rep(0, N+i+n.ahead-1)
+		#}
 		# no look-ahead
 		h = c(sigmafilter[1:(N+i-1)], rep(0, n.ahead))
 		epsx = c(resfilter[1:(N+i-1)], rep(0, n.ahead))
